@@ -5,8 +5,8 @@ from survey.attributes import PositiveMeasureAttribute
 from survey.attributes import RespondentAttribute, SingleCategoryAttribute
 from survey.mixins.data_types.categorical_mixin import CategoricalMixin
 from survey.mixins.data_types.numerical_1d_mixin import Numerical1dMixin
-from survey.questions import SingleChoiceQuestion, MultiChoiceQuestion, LikertQuestion, CountQuestion, \
-    PositiveMeasureQuestion
+from survey.questions import SingleChoiceQuestion, MultiChoiceQuestion, \
+    LikertQuestion, CountQuestion, PositiveMeasureQuestion
 from survey.questions._abstract.question import Question
 
 CategoricalQuestion = Union[CategoricalMixin, Question]
