@@ -1,4 +1,4 @@
-from typing import Dict
+from typing import Dict, Any
 
 from pandas import DataFrame
 
@@ -8,11 +8,12 @@ from survey.mixins.data_types.single_category_mixin import SingleCategoryMixin
 class SingleCategoryGroupComparisonMixin(object):
 
     item_dict: Dict[str, SingleCategoryMixin]
+    __getitem__: Any
 
     def __gt__(self, other: 'SingleCategoryGroupComparisonMixin') -> DataFrame:
         """
-        Find the probability that each answer is more likely to be selected for each pair of questions
-        in this and the other group.
+        Find the probability that each answer is more likely to be selected for
+        each pair of questions in this and the other group.
         """
         results = {}
         for key in self.item_dict.keys():
@@ -21,11 +22,7 @@ class SingleCategoryGroupComparisonMixin(object):
 
     def __lt__(self, other: 'SingleCategoryGroupComparisonMixin') -> DataFrame:
         """
-        Find the probability that each answer is more likely to be selected for each pair of questions
-        in this and the other group.
+        Find the probability that each answer is more likely to be selected for
+        each pair of questions in this and the other group.
         """
         return other.__gt__(self)
-
-    def __getitem__(self, item):
-
-        raise NotImplementedError
