@@ -7,7 +7,7 @@ from mpl_format.axes.axis_utils import new_axes
 from mpl_format.text.text_utils import wrap_text
 from numpy.ma import diag
 from pandas import DataFrame, Series, concat
-from probability.distributions import BetaBinomial
+from probability.distributions import BetaBinomialConjugate
 from seaborn import heatmap
 
 from survey.attributes import CountAttribute
@@ -17,12 +17,12 @@ from survey.attributes import SingleCategoryAttribute
 from survey.custom_types import CategoricalQuestion, Categorical, Numerical
 from survey.groups.attribute_groups.attribute_group import AttributeGroup
 from survey.groups.question_groups.question_group import QuestionGroup
-from survey.questions import Question
 from survey.questions import CountQuestion
 from survey.questions import FreeTextQuestion
 from survey.questions import LikertQuestion
 from survey.questions import MultiChoiceQuestion
 from survey.questions import PositiveMeasureQuestion
+from survey.questions import Question
 from survey.questions import RankedChoiceQuestion
 from survey.questions import SingleChoiceQuestion
 from survey.respondents.respondent import Respondent
@@ -97,6 +97,17 @@ class Survey(QuestionGroup, AttributeGroup, object):
             except:
                 print(f'Warning - could not set dynamic group for {group}')
 
+    def question(self, name: str) -> Optional[Question]:
+        """
+        Return the Question with the given name.
+
+        :param name: Name of the question to return.
+        """
+        try:
+            return [q for q in self._questions if q.name == name][0]
+        except IndexError:
+            return None
+
     @property
     def name(self) -> str:
         """
@@ -389,8 +400,8 @@ class Survey(QuestionGroup, AttributeGroup, object):
                                      condition_category=attribute,
                                      condition_values=ctl_attr_values)
         # create beta-binomial distribution for each group
-        bb_exp = BetaBinomial(alpha=1, beta=1, n=n_exp, m=k_exp)
-        bb_ctl = BetaBinomial(alpha=1, beta=1, n=n_ctl, m=k_ctl)
+        bb_exp = BetaBinomialConjugate(alpha=1, beta=1, n=n_exp, m=k_exp)
+        bb_ctl = BetaBinomialConjugate(alpha=1, beta=1, n=n_ctl, m=k_ctl)
         # calculate probability of superiority of test group
         p_superior = bb_exp > bb_ctl
 
